==> dokuwiki_0.0.20080505.orig.tar.gz: dokuwiki-2008-05-05/lib/plugins/plugin/lang/de/lang.php <==
<?php
/**
 * german language file
 *
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * @author Esther Brunner <esther@kaffeehaus.ch>
 * @author Andreas Gohr <andi@splitbrain.org>
 * @author Michael Klier <chi@chimeric.de>
 */
$lang['menu']                  = 'Plugins verwalten';
$lang['download']              = 'Neues Plugin herunterladen und installieren';
$lang['manage']                = 'Installierte Plugins';
$lang['btn_info']              = 'Info';
$lang['btn_update']            = 'Update';
$lang['btn_delete']            = 'Löschen';
$lang['btn_settings']          = 'Einstellungen';
$lang['btn_download']          = 'Herunterladen';
$lang['btn_enable']            = 'Speichern';
$lang['url']                   = 'URL';
$lang['installed']             = 'Installiert:';
$lang['lastupdate']            = 'Letzte Version:';
$lang['source']                = 'Quelle:';
$lang['unknown']               = 'unbekannt';
$lang['updating']              = 'Lade Update ...';
$lang['updated']               = 'Update von Plugin %s erfolgreich installiert';
$lang['updates']               = 'Die folgenden Plugins wurden erfolgreich aktualisiert';
$lang['update_none']           = 'Keine Updates gefunden.';
$lang['deleting']              = 'Löschen ...';
$lang['deleted']               = 'Plugin %s gelöscht.';
$lang['downloading']           = 'Lade herunter ...';
$lang['downloaded']            = 'Plugin %s erfolgreich installiert';
$lang['downloads']             = 'Die folgenden Plugins wurden erfolgreich installiert:';
$lang['download_none']         = 'Keine Plugins gefunden oder es trat ein Fehler beim Herunterladen auf.';
$lang['plugin']                = 'Plugin:';
$lang['components']            = 'Komponenten';
$lang['noinfo']                = 'Dieses Plugin liefert keine Informationen, möglicherweise ist es fehlerhaft.';
$lang['name']                  = 'Name:';
$lang['date']                  = 'Datum:';
$lang['type']                  = 'Typ:';
$lang['desc']                  = 'Beschreibung:';
$lang['author']                = 'Entwickler:';
$lang['www']                   = 'Web:';
$lang['error']                 = 'Ein unbekannter Fehler ist aufgetreten.';
$lang['error_download']        = 'Konnte das Plugin %s nicht installieren';
$lang['error_badurl']          = 'Wahrscheinlich ungültige URL, konnte keinen Dateinamen ausfindig machen';
$lang['error_dircreate']       = 'Konnte keinen temporären Ordner für die Downloads erstellen';
$lang['error_decompress']      = 'Der Plugin Manager konnte das Plugin archiv nicht entpacken. Entweder ist der Download fehlerhaft oder das Komprimierungsverfahren wird nicht unterstützt. Bitte versuchen Sie es erneut oder downloaden und installieren Sie das Plugin manuell';
$lang['error_copy']            = 'Beim kopieren der Dateien des Plugins trat ein Fehler auf <em>%s</em>: möglicherweise ist die Festplatte voll oder die Dateiberechtigungen falsch. Möglicherweise wurde das Plugin nur teilweise installiert, sie sollten das Plugin manuell entfernen um Instabilitäten zu vermeiden.';
$lang['error_delete']          = 'Es gab einem Fehler beim Versuch das Plugin zu löschen <em>%s</em>. Dies liegt warscheinlich an fehlenden Dateiberechtigungen.';

==> dokuwiki_0.0.20090214b.orig.tar.gz: dokuwiki-2009-02-14/lib/plugins/plugin/lang/de/lang.php <==
<?php
/**
 * german language file
 *
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * @author Esther Brunner <esther@kaffeehaus.ch>
 * @author Andreas Gohr <andi@splitbrain.org>
 * @author Michael Klier <chi@chimeric.de>
 * @author Leo Moll <leo@yeasoft.com>
 * @author Florian Anderiasch <fa@art-core.org>
 * @author Robin Kluth <commi1993@gmail.com>
 * @author Arne Pelka <mail@arnepelka.de>
 */
$lang['menu']                  = 'Plugins verwalten';
$lang['download']              = 'Neues Plugin herunterladen und installieren';
$lang['manage']                = 'Installierte Plugins';
$lang['btn_info']              = 'Info';
$lang['btn_update']            = 'Update';
$lang['btn_delete']            = 'Löschen';
$lang['btn_settings']          = 'Einstellungen';
$lang['btn_download']          = 'Herunterladen';
$lang['btn_enable']            = 'Speichern';
$lang['url']                   = 'URL';
$lang['installed']             = 'Installiert:';
$lang['lastupdate']            = 'Letzte Version:';
$lang['source']                = 'Quelle:';
$lang['unknown']               = 'unbekannt';
$lang['updating']              = 'Lade Update ...';
$lang['updated']               = 'Update von Plugin %s erfolgreich installiert';
$lang['updates']               = 'Die folgenden Plugins wurden erfolgreich aktualisiert';
$lang['update_none']           = 'Keine Updates gefunden.';
$lang['deleting']              = 'Löschen ...';
$lang['deleted']               = 'Plugin %s gelöscht.';
$lang['downloading']           = 'Lade herunter ...';
$lang['downloaded']            = 'Plugin %s erfolgreich installiert';
$lang['downloads']             = 'Die folgenden Plugins wurden erfolgreich installiert:';
$lang['download_none']         = 'Keine Plugins gefunden oder es trat ein Fehler beim Herunterladen auf.';
$lang['plugin']                = 'Plugin:';
$lang['components']            = 'Komponenten';
$lang['noinfo']                = 'Dieses Plugin liefert keine Informationen, möglicherweise ist es fehlerhaft.';
$lang['name']                  = 'Name:';
$lang['date']                  = 'Datum:';
$lang['type']                  = 'Typ:';
$lang['desc']                  = 'Beschreibung:';
$lang['author']                = 'Entwickler:';
$lang['www']                   = 'Web:';
$lang['error']                 = 'Ein unbekannter Fehler ist aufgetreten.';
$lang['error_download']        = 'Konnte das Plugin %s nicht installieren';
$lang['error_badurl']          = 'Wahrscheinlich ungültige URL, konnte keinen Dateinamen ausfindig machen';
$lang['error_dircreate']       = 'Konnte keinen temporären Ordner für die Downloads erstellen';
$lang['error_decompress']      = 'Der Plugin Manager konnte das Plugin archiv nicht entpacken. Entweder ist der Download fehlerhaft oder das Komprimierungsverfahren wird nicht unterstützt. Bitte versuchen Sie es erneut oder downloaden und installieren Sie das Plugin manuell';
$lang['error_copy']            = 'Beim kopieren der Dateien des Plugins trat ein Fehler auf <em>%s</em>: möglicherweise ist die Festplatte voll oder die Dateiberechtigungen falsch. Möglicherweise wurde das Plugin nur teilweise installiert, sie sollten das Plugin manuell entfernen um Instabilitäten zu vermeiden.';
$lang['error_delete']          = 'Es gab einem Fehler beim Versuch das Plugin zu löschen <em>%s</em>. Dies liegt warscheinlich an fehlenden Dateiberechtigungen.';
$lang['enabled']               = 'Plugin %s wurde aktiviert.';
$lang['notenabled']            = 'Plugin %s konnte nicht aktiviert werden, überprüfen Sie die Dateirechte.';
$lang['disabled']              = 'Plugin %s wurde deaktiviert.';
$lang['notdisabled']           = 'Plugin %s konnte nicht deaktiviert werden, überprüfen Sie die Dateirechte.';
